@@ -16,7 +16,7 @@
 ## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 """
 The storage definition
-$Id: FileSystemStorage.py 66036 2008-06-02 14:19:27Z glenfant $
+$Id: FileSystemStorage.py 69084 2008-07-28 14:28:25Z b_mathieu $
 """
 __author__  = ''
 __docformat__ = 'restructuredtext'
@@ -201,7 +201,7 @@ class VirtualBinary(VirtualData):
         return self.size
 
     def absolute_url(self):
-        url = '%(instance_url)s/fss_get/%(name)s' % {
+        url = '%(instance_url)s/%(name)s' % {
             'instance_url': self.instance.absolute_url(),
             'name': self.name,
             }
@@ -424,7 +424,7 @@ class FSSInfo(SimpleItem):
         portal_path = utool.getPortalObject().getPhysicalPath()
         portal_path_len = len(portal_path)
         rel_path = '/'.join(instance.getPhysicalPath()[portal_path_len:])
-        fss_path = '%s/fss_get/%s' % (rel_path, name)
+        fss_path = '%s/%s' % (rel_path, name)
         rdf_args['field_url'] = fss_path
 
         # Get field properties
